from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BotRequest(_message.Message):
    __slots__ = ("db_auth",)
    DB_AUTH_FIELD_NUMBER: _ClassVar[int]
    db_auth: str
    def __init__(self, db_auth: _Optional[str] = ...) -> None: ...

class GlobalStatusData(_message.Message):
    __slots__ = ("bot_id", "total_tether_volume", "total_revenue", "total_finished_transaction_count", "total_bid_krw", "total_ask_krw", "current_price", "krw_gain_per_finished_transaction", "current_krw")
    BOT_ID_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TETHER_VOLUME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_REVENUE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FINISHED_TRANSACTION_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_BID_KRW_FIELD_NUMBER: _ClassVar[int]
    TOTAL_ASK_KRW_FIELD_NUMBER: _ClassVar[int]
    CURRENT_PRICE_FIELD_NUMBER: _ClassVar[int]
    KRW_GAIN_PER_FINISHED_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    CURRENT_KRW_FIELD_NUMBER: _ClassVar[int]
    bot_id: str
    total_tether_volume: float
    total_revenue: float
    total_finished_transaction_count: int
    total_bid_krw: int
    total_ask_krw: int
    current_price: int
    krw_gain_per_finished_transaction: float
    current_krw: int
    def __init__(self, bot_id: _Optional[str] = ..., total_tether_volume: _Optional[float] = ..., total_revenue: _Optional[float] = ..., total_finished_transaction_count: _Optional[int] = ..., total_bid_krw: _Optional[int] = ..., total_ask_krw: _Optional[int] = ..., current_price: _Optional[int] = ..., krw_gain_per_finished_transaction: _Optional[float] = ..., current_krw: _Optional[int] = ...) -> None: ...

class BotTradeMetadata(_message.Message):
    __slots__ = ("bot_id", "ask_exact", "ask_human_readable", "bid_exact", "bid_human_readable")
    BOT_ID_FIELD_NUMBER: _ClassVar[int]
    ASK_EXACT_FIELD_NUMBER: _ClassVar[int]
    ASK_HUMAN_READABLE_FIELD_NUMBER: _ClassVar[int]
    BID_EXACT_FIELD_NUMBER: _ClassVar[int]
    BID_HUMAN_READABLE_FIELD_NUMBER: _ClassVar[int]
    bot_id: str
    ask_exact: str
    ask_human_readable: str
    bid_exact: str
    bid_human_readable: str
    def __init__(self, bot_id: _Optional[str] = ..., ask_exact: _Optional[str] = ..., ask_human_readable: _Optional[str] = ..., bid_exact: _Optional[str] = ..., bid_human_readable: _Optional[str] = ...) -> None: ...

class BotConnectivity(_message.Message):
    __slots__ = ("backend", "upbit")
    BACKEND_FIELD_NUMBER: _ClassVar[int]
    UPBIT_FIELD_NUMBER: _ClassVar[int]
    backend: str
    upbit: str
    def __init__(self, backend: _Optional[str] = ..., upbit: _Optional[str] = ...) -> None: ...

class BotStatChange(_message.Message):
    __slots__ = ("status_code", "message")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    message: str
    def __init__(self, status_code: _Optional[int] = ..., message: _Optional[str] = ...) -> None: ...
