# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tetherhelix_grpc/tetherbot.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tetherhelix_grpc/tetherbot.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tetherhelix_grpc/tetherbot.proto\x12\x10tetherhelix_grpc\"\x1d\n\nBotRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\"\x85\x02\n\x10GlobalStatusData\x12\x0e\n\x06\x62ot_id\x18\x01 \x01(\t\x12\x1b\n\x13total_tether_volume\x18\x02 \x01(\x02\x12\x15\n\rtotal_revenue\x18\x03 \x01(\x02\x12(\n total_finished_transaction_count\x18\x04 \x01(\x03\x12\x15\n\rtotal_bid_krw\x18\x05 \x01(\x03\x12\x15\n\rtotal_ask_krw\x18\x06 \x01(\x03\x12\x15\n\rcurrent_price\x18\x07 \x01(\x03\x12)\n!krw_gain_per_finished_transaction\x18\x08 \x01(\x02\x12\x13\n\x0b\x63urrent_krw\x18\t \x01(\x03\"\x80\x01\n\x10\x42otTradeMetadata\x12\x0e\n\x06\x62ot_id\x18\x01 \x01(\t\x12\x11\n\task_exact\x18\x02 \x01(\t\x12\x1a\n\x12\x61sk_human_readable\x18\x03 \x01(\t\x12\x11\n\tbid_exact\x18\x04 \x01(\t\x12\x1a\n\x12\x62id_human_readable\x18\x05 \x01(\t\"1\n\x0f\x42otConnectivity\x12\x0f\n\x07\x62\x61\x63kend\x18\x01 \x01(\t\x12\r\n\x05upbit\x18\x02 \x01(\t\"5\n\rBotStatChange\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t2\x9d\x03\n\tTetherBot\x12S\n\x0fGetGlobalStatus\x12\x1c.tetherhelix_grpc.BotRequest\x1a\".tetherhelix_grpc.GlobalStatusData\x12R\n\x0eGetBotMetaData\x12\x1c.tetherhelix_grpc.BotRequest\x1a\".tetherhelix_grpc.BotTradeMetadata\x12X\n\x15GetConnectivityStatus\x12\x1c.tetherhelix_grpc.BotRequest\x1a!.tetherhelix_grpc.BotConnectivity\x12\x46\n\x05Start\x12\x1c.tetherhelix_grpc.BotRequest\x1a\x1f.tetherhelix_grpc.BotStatChange\x12\x45\n\x04Stop\x12\x1c.tetherhelix_grpc.BotRequest\x1a\x1f.tetherhelix_grpc.BotStatChangeB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tetherhelix_grpc.tetherbot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_BOTREQUEST']._serialized_start=54
  _globals['_BOTREQUEST']._serialized_end=83
  _globals['_GLOBALSTATUSDATA']._serialized_start=86
  _globals['_GLOBALSTATUSDATA']._serialized_end=347
  _globals['_BOTTRADEMETADATA']._serialized_start=350
  _globals['_BOTTRADEMETADATA']._serialized_end=478
  _globals['_BOTCONNECTIVITY']._serialized_start=480
  _globals['_BOTCONNECTIVITY']._serialized_end=529
  _globals['_BOTSTATCHANGE']._serialized_start=531
  _globals['_BOTSTATCHANGE']._serialized_end=584
  _globals['_TETHERBOT']._serialized_start=587
  _globals['_TETHERBOT']._serialized_end=1000
# @@protoc_insertion_point(module_scope)
