# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tetherhelix_grpc/transaction.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tetherhelix_grpc/transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"tetherhelix_grpc/transaction.proto\x12\x10tetherhelix_grpc\"\xe2\x02\n\x0fTransactionData\x12\x10\n\x08\x62id_uuid\x18\x01 \x01(\t\x12\x16\n\x0e\x62id_created_at\x18\x02 \x01(\t\x12\x11\n\tbid_price\x18\x03 \x01(\x02\x12\x0f\n\x07\x62id_krw\x18\x04 \x01(\x02\x12\x0f\n\x07\x62id_fee\x18\x05 \x01(\x02\x12\x12\n\nbid_failed\x18\x06 \x01(\x05\x12\x12\n\nask_failed\x18\x07 \x01(\x05\x12\x14\n\x0corder_status\x18\x08 \x01(\x05\x12\x15\n\rtether_volume\x18\t \x01(\x02\x12\x15\n\rbid_filled_at\x18\n \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x0b \x01(\t\x12\x16\n\x0e\x61sk_created_at\x18\x0c \x01(\t\x12\x15\n\rask_filled_at\x18\r \x01(\t\x12\x11\n\task_price\x18\x0e \x01(\x02\x12\x0f\n\x07\x61sk_fee\x18\x0f \x01(\t\x12\x0f\n\x07revenue\x18\x10 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x11 \x01(\t\"G\n\x12TransactionRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x02 \x01(\t\x12\x10\n\x08order_by\x18\x03 \x01(\t\"s\n\x18ScopedTransactionRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\x03\x12\x10\n\x08order_by\x18\x05 \x01(\t\"O\n\x14TransactionsResponse\x12\x37\n\x0ctransactions\x18\x01 \x03(\x0b\x32!.tetherhelix_grpc.TransactionData2\xe0\x01\n\x0bTransaction\x12\x66\n\x16GetCurrentTransactions\x12$.tetherhelix_grpc.TransactionRequest\x1a&.tetherhelix_grpc.TransactionsResponse\x12i\n\x13GetPastTransactions\x12*.tetherhelix_grpc.ScopedTransactionRequest\x1a&.tetherhelix_grpc.TransactionsResponseB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tetherhelix_grpc.transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_TRANSACTIONDATA']._serialized_start=57
  _globals['_TRANSACTIONDATA']._serialized_end=411
  _globals['_TRANSACTIONREQUEST']._serialized_start=413
  _globals['_TRANSACTIONREQUEST']._serialized_end=484
  _globals['_SCOPEDTRANSACTIONREQUEST']._serialized_start=486
  _globals['_SCOPEDTRANSACTIONREQUEST']._serialized_end=601
  _globals['_TRANSACTIONSRESPONSE']._serialized_start=603
  _globals['_TRANSACTIONSRESPONSE']._serialized_end=682
  _globals['_TRANSACTION']._serialized_start=685
  _globals['_TRANSACTION']._serialized_end=909
# @@protoc_insertion_point(module_scope)
